CONTENT = """Welcome to WhiteFly!
===================

Create Change
-------------

Create the change by editing the files **update.sql** and **rollback.sql**.


Setting Environments
-------------
Run below command to add a new environment:
```
whitefly env add <env-name> <connection-str>
```


Commit Change
-------------
Run below command to commit your change:
```
whitefly commit -m "Your commit message"
```
"""
